# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from union.internal.common import authorization_pb2 as common_dot_authorization__pb2
from union.internal.common import identifier_pb2 as common_dot_identifier__pb2
from union.internal.validate.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63ommon/policy.proto\x12\x0f\x63loudidl.common\x1a\x1a\x63ommon/authorization.proto\x1a\x17\x63ommon/identifier.proto\x1a\x17validate/validate.proto\"\xa3\x01\n\x06Policy\x12;\n\x02id\x18\x01 \x01(\x0b\x32!.cloudidl.common.PolicyIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\x12:\n\x08\x62indings\x18\x02 \x03(\x0b\x32\x1e.cloudidl.common.PolicyBindingR\x08\x62indings\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\"\x94\x01\n\rPolicyBinding\x12\x42\n\x07role_id\x18\x01 \x01(\x0b\x32\x1f.cloudidl.common.RoleIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x06roleId\x12?\n\x08resource\x18\x02 \x01(\x0b\x32\x19.cloudidl.common.ResourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08resourceB\xac\x01\n\x13\x63om.cloudidl.commonB\x0bPolicyProtoH\x02P\x01Z)github.com/unionai/cloud/gen/pb-go/common\xa2\x02\x03\x43\x43X\xaa\x02\x0f\x43loudidl.Common\xca\x02\x0f\x43loudidl\\Common\xe2\x02\x1b\x43loudidl\\Common\\GPBMetadata\xea\x02\x10\x43loudidl::Commonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.policy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023com.cloudidl.commonB\013PolicyProtoH\002P\001Z)github.com/unionai/cloud/gen/pb-go/common\242\002\003CCX\252\002\017Cloudidl.Common\312\002\017Cloudidl\\Common\342\002\033Cloudidl\\Common\\GPBMetadata\352\002\020Cloudidl::Common'
  _POLICY.fields_by_name['id']._options = None
  _POLICY.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _POLICYBINDING.fields_by_name['role_id']._options = None
  _POLICYBINDING.fields_by_name['role_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _POLICYBINDING.fields_by_name['resource']._options = None
  _POLICYBINDING.fields_by_name['resource']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_POLICY']._serialized_start=119
  _globals['_POLICY']._serialized_end=282
  _globals['_POLICYBINDING']._serialized_start=285
  _globals['_POLICYBINDING']._serialized_end=433
# @@protoc_insertion_point(module_scope)
