# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/authorization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from union.internal.common import identifier_pb2 as common_dot_identifier__pb2
from union.internal.validate.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63ommon/authorization.proto\x12\x0f\x63loudidl.common\x1a\x17\x63ommon/identifier.proto\x1a\x17validate/validate.proto\"+\n\x0cOrganization\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\"i\n\x06\x44omain\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12K\n\x0corganization\x18\x02 \x01(\x0b\x32\x1d.cloudidl.common.OrganizationB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0corganization\"a\n\x07Project\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12\x39\n\x06\x64omain\x18\x02 \x01(\x0b\x32\x17.cloudidl.common.DomainB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x06\x64omain\"e\n\x08Workflow\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12<\n\x07project\x18\x02 \x01(\x0b\x32\x18.cloudidl.common.ProjectB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x07project\"g\n\nLaunchPlan\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12<\n\x07project\x18\x02 \x01(\x0b\x32\x18.cloudidl.common.ProjectB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x07project\"\xfd\x02\n\x08Resource\x12\x43\n\x0corganization\x18\x01 \x01(\x0b\x32\x1d.cloudidl.common.OrganizationH\x00R\x0corganization\x12\x31\n\x06\x64omain\x18\x02 \x01(\x0b\x32\x17.cloudidl.common.DomainH\x00R\x06\x64omain\x12\x34\n\x07project\x18\x03 \x01(\x0b\x32\x18.cloudidl.common.ProjectH\x00R\x07project\x12\x37\n\x08workflow\x18\x04 \x01(\x0b\x32\x19.cloudidl.common.WorkflowH\x00R\x08workflow\x12>\n\x0blaunch_plan\x18\x05 \x01(\x0b\x32\x1b.cloudidl.common.LaunchPlanH\x00R\nlaunchPlan\x12>\n\x07\x63luster\x18\x06 \x01(\x0b\x32\".cloudidl.common.ClusterIdentifierH\x00R\x07\x63lusterB\n\n\x08resource\"v\n\nPermission\x12\x35\n\x08resource\x18\x01 \x01(\x0b\x32\x19.cloudidl.common.ResourceR\x08resource\x12\x31\n\x07\x61\x63tions\x18\x02 \x03(\x0e\x32\x17.cloudidl.common.ActionR\x07\x61\x63tions*\xf4\x03\n\x06\x41\x63tion\x12\x0f\n\x0b\x41\x43TION_NONE\x10\x00\x12\x15\n\rACTION_CREATE\x10\x01\x1a\x02\x08\x01\x12\x13\n\x0b\x41\x43TION_READ\x10\x02\x1a\x02\x08\x01\x12\x15\n\rACTION_UPDATE\x10\x03\x1a\x02\x08\x01\x12\x15\n\rACTION_DELETE\x10\x04\x1a\x02\x08\x01\x12\x1f\n\x1b\x41\x43TION_VIEW_FLYTE_INVENTORY\x10\x05\x12 \n\x1c\x41\x43TION_VIEW_FLYTE_EXECUTIONS\x10\x06\x12#\n\x1f\x41\x43TION_REGISTER_FLYTE_INVENTORY\x10\x07\x12\"\n\x1e\x41\x43TION_CREATE_FLYTE_EXECUTIONS\x10\x08\x12\x1d\n\x19\x41\x43TION_ADMINISTER_PROJECT\x10\t\x12\x1d\n\x19\x41\x43TION_MANAGE_PERMISSIONS\x10\n\x12\x1d\n\x19\x41\x43TION_ADMINISTER_ACCOUNT\x10\x0b\x12\x19\n\x15\x41\x43TION_MANAGE_CLUSTER\x10\x0c\x12,\n(ACTION_EDIT_EXECUTION_RELATED_ATTRIBUTES\x10\r\x12*\n&ACTION_EDIT_CLUSTER_RELATED_ATTRIBUTES\x10\x0e\x12!\n\x1d\x41\x43TION_EDIT_UNUSED_ATTRIBUTES\x10\x0f\x42\xb3\x01\n\x13\x63om.cloudidl.commonB\x12\x41uthorizationProtoH\x02P\x01Z)github.com/unionai/cloud/gen/pb-go/common\xa2\x02\x03\x43\x43X\xaa\x02\x0f\x43loudidl.Common\xca\x02\x0f\x43loudidl\\Common\xe2\x02\x1b\x43loudidl\\Common\\GPBMetadata\xea\x02\x10\x43loudidl::Commonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.authorization_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023com.cloudidl.commonB\022AuthorizationProtoH\002P\001Z)github.com/unionai/cloud/gen/pb-go/common\242\002\003CCX\252\002\017Cloudidl.Common\312\002\017Cloudidl\\Common\342\002\033Cloudidl\\Common\\GPBMetadata\352\002\020Cloudidl::Common'
  _ACTION.values_by_name["ACTION_CREATE"]._options = None
  _ACTION.values_by_name["ACTION_CREATE"]._serialized_options = b'\010\001'
  _ACTION.values_by_name["ACTION_READ"]._options = None
  _ACTION.values_by_name["ACTION_READ"]._serialized_options = b'\010\001'
  _ACTION.values_by_name["ACTION_UPDATE"]._options = None
  _ACTION.values_by_name["ACTION_UPDATE"]._serialized_options = b'\010\001'
  _ACTION.values_by_name["ACTION_DELETE"]._options = None
  _ACTION.values_by_name["ACTION_DELETE"]._serialized_options = b'\010\001'
  _ORGANIZATION.fields_by_name['name']._options = None
  _ORGANIZATION.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _DOMAIN.fields_by_name['organization']._options = None
  _DOMAIN.fields_by_name['organization']._serialized_options = b'\372B\005\212\001\002\020\001'
  _PROJECT.fields_by_name['name']._options = None
  _PROJECT.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _PROJECT.fields_by_name['domain']._options = None
  _PROJECT.fields_by_name['domain']._serialized_options = b'\372B\005\212\001\002\020\001'
  _WORKFLOW.fields_by_name['name']._options = None
  _WORKFLOW.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _WORKFLOW.fields_by_name['project']._options = None
  _WORKFLOW.fields_by_name['project']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LAUNCHPLAN.fields_by_name['name']._options = None
  _LAUNCHPLAN.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _LAUNCHPLAN.fields_by_name['project']._options = None
  _LAUNCHPLAN.fields_by_name['project']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_ACTION']._serialized_start=1061
  _globals['_ACTION']._serialized_end=1561
  _globals['_ORGANIZATION']._serialized_start=97
  _globals['_ORGANIZATION']._serialized_end=140
  _globals['_DOMAIN']._serialized_start=142
  _globals['_DOMAIN']._serialized_end=247
  _globals['_PROJECT']._serialized_start=249
  _globals['_PROJECT']._serialized_end=346
  _globals['_WORKFLOW']._serialized_start=348
  _globals['_WORKFLOW']._serialized_end=449
  _globals['_LAUNCHPLAN']._serialized_start=451
  _globals['_LAUNCHPLAN']._serialized_end=554
  _globals['_RESOURCE']._serialized_start=557
  _globals['_RESOURCE']._serialized_end=938
  _globals['_PERMISSION']._serialized_start=940
  _globals['_PERMISSION']._serialized_end=1058
# @@protoc_insertion_point(module_scope)
