# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hooks/payload.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.event import cloudevents_pb2 as flyteidl_dot_event_dot_cloudevents__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13hooks/payload.proto\x12\x0e\x63loudidl.hooks\x1a flyteidl/event/cloudevents.proto\"J\n\x0c\x45ventFilters\x12:\n\x0b\x65vent_types\x18\x01 \x03(\x0e\x32\x19.cloudidl.hooks.EventTypeR\neventTypes\"M\n\x13StreamEventsRequest\x12\x36\n\x07\x66ilters\x18\x01 \x01(\x0b\x32\x1c.cloudidl.hooks.EventFiltersR\x07\x66ilters\"\xb1\x02\n\x14StreamEventsResponse\x12\\\n\x12workflow_execution\x18\x01 \x01(\x0b\x32+.flyteidl.event.CloudEventWorkflowExecutionH\x00R\x11workflowExecution\x12P\n\x0enode_execution\x18\x02 \x01(\x0b\x32\'.flyteidl.event.CloudEventNodeExecutionH\x00R\rnodeExecution\x12P\n\x0etask_execution\x18\x03 \x01(\x0b\x32\'.flyteidl.event.CloudEventTaskExecutionH\x00R\rtaskExecution\x12\x0e\n\x02id\x18\x04 \x01(\tR\x02idB\x07\n\x05\x65vent\")\n\x17\x41\x63knowledgeEventRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x1a\n\x18\x41\x63knowledgeEventResponse*\\\n\tEventType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x16\n\x12WORKFLOW_EXECUTION\x10\x01\x12\x12\n\x0eNODE_EXECUTION\x10\x02\x12\x12\n\x0eTASK_EXECUTION\x10\x03\x42\xa7\x01\n\x12\x63om.cloudidl.hooksB\x0cPayloadProtoH\x02P\x01Z(github.com/unionai/cloud/gen/pb-go/hooks\xa2\x02\x03\x43HX\xaa\x02\x0e\x43loudidl.Hooks\xca\x02\x0e\x43loudidl\\Hooks\xe2\x02\x1a\x43loudidl\\Hooks\\GPBMetadata\xea\x02\x0f\x43loudidl::Hooksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hooks.payload_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022com.cloudidl.hooksB\014PayloadProtoH\002P\001Z(github.com/unionai/cloud/gen/pb-go/hooks\242\002\003CHX\252\002\016Cloudidl.Hooks\312\002\016Cloudidl\\Hooks\342\002\032Cloudidl\\Hooks\\GPBMetadata\352\002\017Cloudidl::Hooks'
  _globals['_EVENTTYPE']._serialized_start=607
  _globals['_EVENTTYPE']._serialized_end=699
  _globals['_EVENTFILTERS']._serialized_start=73
  _globals['_EVENTFILTERS']._serialized_end=147
  _globals['_STREAMEVENTSREQUEST']._serialized_start=149
  _globals['_STREAMEVENTSREQUEST']._serialized_end=226
  _globals['_STREAMEVENTSRESPONSE']._serialized_start=229
  _globals['_STREAMEVENTSRESPONSE']._serialized_end=534
  _globals['_ACKNOWLEDGEEVENTREQUEST']._serialized_start=536
  _globals['_ACKNOWLEDGEEVENTREQUEST']._serialized_end=577
  _globals['_ACKNOWLEDGEEVENTRESPONSE']._serialized_start=579
  _globals['_ACKNOWLEDGEEVENTRESPONSE']._serialized_end=605
# @@protoc_insertion_point(module_scope)
