# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/role.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from union.internal.common import authorization_pb2 as common_dot_authorization__pb2
from union.internal.common import identifier_pb2 as common_dot_identifier__pb2
from union.internal.validate.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63ommon/role.proto\x12\x0f\x63loudidl.common\x1a\x1a\x63ommon/authorization.proto\x1a\x17\x63ommon/identifier.proto\x1a\x17validate/validate.proto\"\xa7\x02\n\x04Role\x12\x39\n\x02id\x18\x01 \x01(\x0b\x32\x1f.cloudidl.common.RoleIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\x12\x41\n\x0bpermissions\x18\x02 \x03(\x0b\x32\x1b.cloudidl.common.PermissionB\x02\x18\x01R\x0bpermissions\x12\x36\n\trole_spec\x18\x03 \x01(\x0b\x32\x19.cloudidl.common.RoleSpecR\x08roleSpec\x12\x36\n\trole_type\x18\x04 \x01(\x0e\x32\x19.cloudidl.common.RoleTypeR\x08roleType\x12\x31\n\x07\x61\x63tions\x18\x05 \x03(\x0e\x32\x17.cloudidl.common.ActionR\x07\x61\x63tions\",\n\x08RoleSpec\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription*\x83\x02\n\x08RoleType\x12\x12\n\x0eROLE_TYPE_NONE\x10\x00\x12\x13\n\x0fROLE_TYPE_ADMIN\x10\x01\x12\x19\n\x15ROLE_TYPE_CONTRIBUTOR\x10\x02\x12\x14\n\x10ROLE_TYPE_VIEWER\x10\x03\x12\x14\n\x10ROLE_TYPE_CUSTOM\x10\x04\x12\x1d\n\x19ROLE_TYPE_CLUSTER_MANAGER\x10\x05\x12!\n\x1dROLE_TYPE_FLYTE_PROJECT_ADMIN\x10\x06\x12\x1f\n\x1bROLE_TYPE_SERVERLESS_VIEWER\x10\x07\x12$\n ROLE_TYPE_SERVERLESS_CONTRIBUTOR\x10\x08\x42\xaa\x01\n\x13\x63om.cloudidl.commonB\tRoleProtoH\x02P\x01Z)github.com/unionai/cloud/gen/pb-go/common\xa2\x02\x03\x43\x43X\xaa\x02\x0f\x43loudidl.Common\xca\x02\x0f\x43loudidl\\Common\xe2\x02\x1b\x43loudidl\\Common\\GPBMetadata\xea\x02\x10\x43loudidl::Commonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.role_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023com.cloudidl.commonB\tRoleProtoH\002P\001Z)github.com/unionai/cloud/gen/pb-go/common\242\002\003CCX\252\002\017Cloudidl.Common\312\002\017Cloudidl\\Common\342\002\033Cloudidl\\Common\\GPBMetadata\352\002\020Cloudidl::Common'
  _ROLE.fields_by_name['id']._options = None
  _ROLE.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ROLE.fields_by_name['permissions']._options = None
  _ROLE.fields_by_name['permissions']._serialized_options = b'\030\001'
  _globals['_ROLETYPE']._serialized_start=461
  _globals['_ROLETYPE']._serialized_end=720
  _globals['_ROLE']._serialized_start=117
  _globals['_ROLE']._serialized_end=412
  _globals['_ROLESPEC']._serialized_start=414
  _globals['_ROLESPEC']._serialized_end=458
# @@protoc_insertion_point(module_scope)
