# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: logs/dataplane/payload.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from union.internal.validate.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1clogs/dataplane/payload.proto\x12\x17\x63loudidl.logs.dataplane\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\"o\n\x0bPodResource\x12%\n\tnamespace\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\tnamespace\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12\x1c\n\tcontainer\x18\x03 \x01(\tR\tcontainer\"\xda\x01\n\x1cTailTaskExecutionLogsRequest\x12Z\n\x0flogging_context\x18\x01 \x01(\x0b\x32\'.cloudidl.logs.dataplane.LoggingContextB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0eloggingContext\x12;\n\x06source\x18\x03 \x01(\x0e\x32#.cloudidl.logs.dataplane.LogsSourceR\x06source\x12\x1b\n\tno_follow\x18\x04 \x01(\x08R\x08noFollowJ\x04\x08\x02\x10\x03\"\xeb\x01\n\x1dTailTaskExecutionLogsResponse\x12Q\n\x04logs\x18\x01 \x01(\x0b\x32;.cloudidl.logs.dataplane.TailTaskExecutionLogsResponse.LogsH\x00R\x04logs\x1am\n\x04Logs\x12\x18\n\x05lines\x18\x01 \x03(\tB\x02\x18\x01R\x05lines\x12K\n\x10structured_lines\x18\x02 \x03(\x0b\x32 .cloudidl.logs.dataplane.LogLineR\x0fstructuredLinesB\x08\n\x06result\"\xb8\x03\n\x0eLoggingContext\x12*\n\x0c\x63luster_name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x63lusterName\x12:\n\x14kubernetes_namespace\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13kubernetesNamespace\x12\x37\n\x13kubernetes_pod_name\x18\x05 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x11kubernetesPodName\x12\x43\n\x19kubernetes_container_name\x18\x06 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x17kubernetesContainerName\x12[\n\x1c\x65xecution_attempt_start_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x19\x65xecutionAttemptStartTime\x12W\n\x1a\x65xecution_attempt_end_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x17\x65xecutionAttemptEndTimeJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"\xf2\x01\n\x13\x43ontainerIdentifier\x12*\n\x0c\x63luster_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x63lusterName\x12:\n\x14kubernetes_namespace\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13kubernetesNamespace\x12\x37\n\x13kubernetes_pod_name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x11kubernetesPodName\x12:\n\x19kubernetes_container_name\x18\x04 \x01(\tR\x17kubernetesContainerName\"\xb7\x02\n\x11\x43ontainerSelector\x12*\n\x0c\x63luster_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x63lusterName\x12:\n\x14kubernetes_namespace\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13kubernetesNamespace\x12;\n\x1akubernetes_pod_name_prefix\x18\x03 \x01(\tR\x17kubernetesPodNamePrefix\x12:\n\x19kubernetes_container_name\x18\x04 \x01(\tR\x17kubernetesContainerName\x12\x41\n\x1dkubernetes_pod_label_selector\x18\x05 \x01(\tR\x1akubernetesPodLabelSelector\"^\n\x0fLiveLogsOptions\x12$\n\x0elog_pod_status\x18\x01 \x01(\x08R\x0clogPodStatus\x12%\n\x0elog_timestamps\x18\x02 \x01(\x08R\rlogTimestamps\"\xd5\x03\n\x0fTailLogsRequest\x12L\n\tcontainer\x18\x01 \x01(\x0b\x32,.cloudidl.logs.dataplane.ContainerIdentifierH\x00R\tcontainer\x12[\n\x12\x63ontainer_selector\x18\x02 \x01(\x0b\x32*.cloudidl.logs.dataplane.ContainerSelectorH\x00R\x11\x63ontainerSelector\x12\x43\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xfa\x42\x05\xb2\x01\x02\x08\x01R\tstartTime\x12\x35\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12;\n\x06source\x18\x05 \x01(\x0e\x32#.cloudidl.logs.dataplane.LogsSourceR\x06source\x12T\n\x11live_logs_options\x18\x06 \x01(\x0b\x32(.cloudidl.logs.dataplane.LiveLogsOptionsR\x0fliveLogsOptionsB\x08\n\x06target\"\xa9\x01\n\x07LogLine\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12J\n\noriginator\x18\x03 \x01(\x0e\x32*.cloudidl.logs.dataplane.LogLineOriginatorR\noriginator\"\xf0\x01\n\x08LogLines\x12\x18\n\x05lines\x18\x01 \x03(\tB\x02\x18\x01R\x05lines\x12\'\n\x0f\x63ontainer_index\x18\x02 \x01(\rR\x0e\x63ontainerIndex\x12T\n\tcontainer\x18\x03 \x01(\x0b\x32,.cloudidl.logs.dataplane.ContainerIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\tcontainer\x12K\n\x10structured_lines\x18\x04 \x03(\x0b\x32 .cloudidl.logs.dataplane.LogLineR\x0fstructuredLines\"a\n\x11LogContainersList\x12L\n\ncontainers\x18\x01 \x03(\x0b\x32,.cloudidl.logs.dataplane.ContainerIdentifierR\ncontainers\"F\n\rLogLinesBatch\x12\x35\n\x04logs\x18\x01 \x03(\x0b\x32!.cloudidl.logs.dataplane.LogLinesR\x04logs\"\xd9\x01\n\x10TailLogsResponse\x12V\n\ncontainers\x18\x01 \x01(\x0b\x32*.cloudidl.logs.dataplane.LogContainersListB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00R\ncontainers\x12Z\n\x0flog_lines_batch\x18\x03 \x01(\x0b\x32&.cloudidl.logs.dataplane.LogLinesBatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00R\rlogLinesBatchB\x0b\n\x04resp\x12\x03\xf8\x42\x01J\x04\x08\x02\x10\x03*6\n\x11LogLineOriginator\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04USER\x10\x01\x12\n\n\x06SYSTEM\x10\x02*F\n\nLogsSource\x12\x15\n\x11LIVE_OR_PERSISTED\x10\x00\x12\r\n\tLIVE_ONLY\x10\x01\x12\x12\n\x0ePERSISTED_ONLY\x10\x02\x42\xde\x01\n\x1b\x63om.cloudidl.logs.dataplaneB\x0cPayloadProtoH\x02P\x01Z1github.com/unionai/cloud/gen/pb-go/logs/dataplane\xa2\x02\x03\x43LD\xaa\x02\x17\x43loudidl.Logs.Dataplane\xca\x02\x17\x43loudidl\\Logs\\Dataplane\xe2\x02#Cloudidl\\Logs\\Dataplane\\GPBMetadata\xea\x02\x19\x43loudidl::Logs::Dataplaneb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'logs.dataplane.payload_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.cloudidl.logs.dataplaneB\014PayloadProtoH\002P\001Z1github.com/unionai/cloud/gen/pb-go/logs/dataplane\242\002\003CLD\252\002\027Cloudidl.Logs.Dataplane\312\002\027Cloudidl\\Logs\\Dataplane\342\002#Cloudidl\\Logs\\Dataplane\\GPBMetadata\352\002\031Cloudidl::Logs::Dataplane'
  _PODRESOURCE.fields_by_name['namespace']._options = None
  _PODRESOURCE.fields_by_name['namespace']._serialized_options = b'\372B\004r\002\020\001'
  _PODRESOURCE.fields_by_name['name']._options = None
  _PODRESOURCE.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _TAILTASKEXECUTIONLOGSREQUEST.fields_by_name['logging_context']._options = None
  _TAILTASKEXECUTIONLOGSREQUEST.fields_by_name['logging_context']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TAILTASKEXECUTIONLOGSRESPONSE_LOGS.fields_by_name['lines']._options = None
  _TAILTASKEXECUTIONLOGSRESPONSE_LOGS.fields_by_name['lines']._serialized_options = b'\030\001'
  _LOGGINGCONTEXT.fields_by_name['cluster_name']._options = None
  _LOGGINGCONTEXT.fields_by_name['cluster_name']._serialized_options = b'\372B\004r\002\020\001'
  _LOGGINGCONTEXT.fields_by_name['kubernetes_namespace']._options = None
  _LOGGINGCONTEXT.fields_by_name['kubernetes_namespace']._serialized_options = b'\372B\004r\002\020\001'
  _LOGGINGCONTEXT.fields_by_name['kubernetes_pod_name']._options = None
  _LOGGINGCONTEXT.fields_by_name['kubernetes_pod_name']._serialized_options = b'\372B\004r\002\020\001'
  _LOGGINGCONTEXT.fields_by_name['kubernetes_container_name']._options = None
  _LOGGINGCONTEXT.fields_by_name['kubernetes_container_name']._serialized_options = b'\372B\004r\002\020\001'
  _CONTAINERIDENTIFIER.fields_by_name['cluster_name']._options = None
  _CONTAINERIDENTIFIER.fields_by_name['cluster_name']._serialized_options = b'\372B\004r\002\020\001'
  _CONTAINERIDENTIFIER.fields_by_name['kubernetes_namespace']._options = None
  _CONTAINERIDENTIFIER.fields_by_name['kubernetes_namespace']._serialized_options = b'\372B\004r\002\020\001'
  _CONTAINERIDENTIFIER.fields_by_name['kubernetes_pod_name']._options = None
  _CONTAINERIDENTIFIER.fields_by_name['kubernetes_pod_name']._serialized_options = b'\372B\004r\002\020\001'
  _CONTAINERSELECTOR.fields_by_name['cluster_name']._options = None
  _CONTAINERSELECTOR.fields_by_name['cluster_name']._serialized_options = b'\372B\004r\002\020\001'
  _CONTAINERSELECTOR.fields_by_name['kubernetes_namespace']._options = None
  _CONTAINERSELECTOR.fields_by_name['kubernetes_namespace']._serialized_options = b'\372B\004r\002\020\001'
  _TAILLOGSREQUEST.fields_by_name['start_time']._options = None
  _TAILLOGSREQUEST.fields_by_name['start_time']._serialized_options = b'\372B\005\262\001\002\010\001'
  _LOGLINES.fields_by_name['lines']._options = None
  _LOGLINES.fields_by_name['lines']._serialized_options = b'\030\001'
  _LOGLINES.fields_by_name['container']._options = None
  _LOGLINES.fields_by_name['container']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TAILLOGSRESPONSE.oneofs_by_name['resp']._options = None
  _TAILLOGSRESPONSE.oneofs_by_name['resp']._serialized_options = b'\370B\001'
  _TAILLOGSRESPONSE.fields_by_name['containers']._options = None
  _TAILLOGSRESPONSE.fields_by_name['containers']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TAILLOGSRESPONSE.fields_by_name['log_lines_batch']._options = None
  _TAILLOGSRESPONSE.fields_by_name['log_lines_batch']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_LOGLINEORIGINATOR']._serialized_start=3063
  _globals['_LOGLINEORIGINATOR']._serialized_end=3117
  _globals['_LOGSSOURCE']._serialized_start=3119
  _globals['_LOGSSOURCE']._serialized_end=3189
  _globals['_PODRESOURCE']._serialized_start=115
  _globals['_PODRESOURCE']._serialized_end=226
  _globals['_TAILTASKEXECUTIONLOGSREQUEST']._serialized_start=229
  _globals['_TAILTASKEXECUTIONLOGSREQUEST']._serialized_end=447
  _globals['_TAILTASKEXECUTIONLOGSRESPONSE']._serialized_start=450
  _globals['_TAILTASKEXECUTIONLOGSRESPONSE']._serialized_end=685
  _globals['_TAILTASKEXECUTIONLOGSRESPONSE_LOGS']._serialized_start=566
  _globals['_TAILTASKEXECUTIONLOGSRESPONSE_LOGS']._serialized_end=675
  _globals['_LOGGINGCONTEXT']._serialized_start=688
  _globals['_LOGGINGCONTEXT']._serialized_end=1128
  _globals['_CONTAINERIDENTIFIER']._serialized_start=1131
  _globals['_CONTAINERIDENTIFIER']._serialized_end=1373
  _globals['_CONTAINERSELECTOR']._serialized_start=1376
  _globals['_CONTAINERSELECTOR']._serialized_end=1687
  _globals['_LIVELOGSOPTIONS']._serialized_start=1689
  _globals['_LIVELOGSOPTIONS']._serialized_end=1783
  _globals['_TAILLOGSREQUEST']._serialized_start=1786
  _globals['_TAILLOGSREQUEST']._serialized_end=2255
  _globals['_LOGLINE']._serialized_start=2258
  _globals['_LOGLINE']._serialized_end=2427
  _globals['_LOGLINES']._serialized_start=2430
  _globals['_LOGLINES']._serialized_end=2670
  _globals['_LOGCONTAINERSLIST']._serialized_start=2672
  _globals['_LOGCONTAINERSLIST']._serialized_end=2769
  _globals['_LOGLINESBATCH']._serialized_start=2771
  _globals['_LOGLINESBATCH']._serialized_end=2841
  _globals['_TAILLOGSRESPONSE']._serialized_start=2844
  _globals['_TAILLOGSRESPONSE']._serialized_end=3061
# @@protoc_insertion_point(module_scope)
