# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workspace/workspace_instance_payload.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from union.internal.common import identifier_pb2 as common_dot_identifier__pb2
from union.internal.common import list_pb2 as common_dot_list__pb2
from flyteidl.admin import execution_pb2 as flyteidl_dot_admin_dot_execution__pb2
from flyteidl.core import literals_pb2 as flyteidl_dot_core_dot_literals__pb2
from union.internal.validate.validate import validate_pb2 as validate_dot_validate__pb2
from union.internal.workspace import workspace_definition_pb2 as workspace_dot_workspace__definition__pb2
from union.internal.workspace import workspace_instance_pb2 as workspace_dot_workspace__instance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*workspace/workspace_instance_payload.proto\x12\x12\x63loudidl.workspace\x1a\x17\x63ommon/identifier.proto\x1a\x11\x63ommon/list.proto\x1a\x1e\x66lyteidl/admin/execution.proto\x1a\x1c\x66lyteidl/core/literals.proto\x1a\x17validate/validate.proto\x1a$workspace/workspace_definition.proto\x1a\"workspace/workspace_instance.proto\"\xe4\x02\n\x1dStartWorkspaceInstanceRequest\x12\x10\n\x03org\x18\x01 \x01(\tR\x03org\x12!\n\x07project\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x07project\x12\x1f\n\x06\x64omain\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06\x64omain\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12s\n\x17workspace_definition_id\x18\x05 \x01(\x0b\x32\x31.cloudidl.workspace.WorkspaceDefinitionIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x15workspaceDefinitionId\x12\x31\n\x04spec\x18\x06 \x01(\x0b\x32\x1d.flyteidl.admin.ExecutionSpecR\x04spec\x12\x31\n\x06inputs\x18\x07 \x01(\x0b\x32\x19.flyteidl.core.LiteralMapR\x06inputs\"v\n\x1eStartWorkspaceInstanceResponse\x12T\n\x12workspace_instance\x18\x01 \x01(\x0b\x32%.cloudidl.workspace.WorkspaceInstanceR\x11workspaceInstance\"^\n\x1bGetWorkspaceInstanceRequest\x12?\n\x02id\x18\x01 \x01(\x0b\x32/.cloudidl.workspace.WorkspaceInstanceIdentifierR\x02id\"t\n\x1cGetWorkspaceInstanceResponse\x12T\n\x12workspace_instance\x18\x01 \x01(\x0b\x32%.cloudidl.workspace.WorkspaceInstanceR\x11workspaceInstance\"\xf0\x02\n\x1dListWorkspaceInstancesRequest\x12\x36\n\x07request\x18\x01 \x01(\x0b\x32\x1c.cloudidl.common.ListRequestR\x07request\x12\x1b\n\x03org\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00R\x03org\x12H\n\x07project\x18\x03 \x01(\x0b\x32\".cloudidl.common.ProjectIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00R\x07project\x12u\n\x17workspace_definition_id\x18\x04 \x01(\x0b\x32\x31.cloudidl.workspace.WorkspaceDefinitionIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00R\x15workspaceDefinitionId\x12\'\n\tprincipal\x18\x05 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00R\tprincipalB\x10\n\tfilter_by\x12\x03\xf8\x42\x01\"\x8e\x01\n\x1eListWorkspaceInstancesResponse\x12V\n\x13workspace_instances\x18\x01 \x03(\x0b\x32%.cloudidl.workspace.WorkspaceInstanceR\x12workspaceInstances\x12\x14\n\x05token\x18\x02 \x01(\tR\x05token\"\xa7\x03\n\x1eWatchWorkspaceInstancesRequest\x12\x1b\n\x03org\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00R\x03org\x12H\n\x07project\x18\x02 \x01(\x0b\x32\".cloudidl.common.ProjectIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00R\x07project\x12u\n\x17workspace_definition_id\x18\x03 \x01(\x0b\x32\x31.cloudidl.workspace.WorkspaceDefinitionIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00R\x15workspaceDefinitionId\x12o\n\x15workspace_instance_id\x18\x04 \x01(\x0b\x32/.cloudidl.workspace.WorkspaceInstanceIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00R\x13workspaceInstanceId\x12\'\n\tprincipal\x18\x05 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00R\tprincipalB\r\n\x06target\x12\x03\xf8\x42\x01\"\xbf\x02\n\x1fWatchWorkspaceInstancesResponse\x12\x41\n\x0bstart_event\x18\x01 \x01(\x0b\x32\x1e.cloudidl.workspace.StartEventH\x00R\nstartEvent\x12\x44\n\x0cupdate_event\x18\x02 \x01(\x0b\x32\x1f.cloudidl.workspace.UpdateEventH\x00R\x0bupdateEvent\x12>\n\nstop_event\x18\x03 \x01(\x0b\x32\x1d.cloudidl.workspace.StopEventH\x00R\tstopEvent\x12J\n\x0estopping_event\x18\x04 \x01(\x0b\x32!.cloudidl.workspace.StoppingEventH\x00R\rstoppingEventB\x07\n\x05\x65vent\"\x7f\n\x1cStopWorkspaceInstanceRequest\x12I\n\x02id\x18\x01 \x01(\x0b\x32/.cloudidl.workspace.WorkspaceInstanceIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\x12\x14\n\x05\x63\x61use\x18\x02 \x01(\tR\x05\x63\x61use\"\x1f\n\x1dStopWorkspaceInstanceResponseB\xd0\x01\n\x16\x63om.cloudidl.workspaceB\x1dWorkspaceInstancePayloadProtoH\x02P\x01Z,github.com/unionai/cloud/gen/pb-go/workspace\xa2\x02\x03\x43WX\xaa\x02\x12\x43loudidl.Workspace\xca\x02\x12\x43loudidl\\Workspace\xe2\x02\x1e\x43loudidl\\Workspace\\GPBMetadata\xea\x02\x13\x43loudidl::Workspaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'workspace.workspace_instance_payload_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.cloudidl.workspaceB\035WorkspaceInstancePayloadProtoH\002P\001Z,github.com/unionai/cloud/gen/pb-go/workspace\242\002\003CWX\252\002\022Cloudidl.Workspace\312\002\022Cloudidl\\Workspace\342\002\036Cloudidl\\Workspace\\GPBMetadata\352\002\023Cloudidl::Workspace'
  _STARTWORKSPACEINSTANCEREQUEST.fields_by_name['project']._options = None
  _STARTWORKSPACEINSTANCEREQUEST.fields_by_name['project']._serialized_options = b'\372B\004r\002\020\001'
  _STARTWORKSPACEINSTANCEREQUEST.fields_by_name['domain']._options = None
  _STARTWORKSPACEINSTANCEREQUEST.fields_by_name['domain']._serialized_options = b'\372B\004r\002\020\001'
  _STARTWORKSPACEINSTANCEREQUEST.fields_by_name['workspace_definition_id']._options = None
  _STARTWORKSPACEINSTANCEREQUEST.fields_by_name['workspace_definition_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTWORKSPACEINSTANCESREQUEST.oneofs_by_name['filter_by']._options = None
  _LISTWORKSPACEINSTANCESREQUEST.oneofs_by_name['filter_by']._serialized_options = b'\370B\001'
  _LISTWORKSPACEINSTANCESREQUEST.fields_by_name['org']._options = None
  _LISTWORKSPACEINSTANCESREQUEST.fields_by_name['org']._serialized_options = b'\372B\004r\002\020\001'
  _LISTWORKSPACEINSTANCESREQUEST.fields_by_name['project']._options = None
  _LISTWORKSPACEINSTANCESREQUEST.fields_by_name['project']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTWORKSPACEINSTANCESREQUEST.fields_by_name['workspace_definition_id']._options = None
  _LISTWORKSPACEINSTANCESREQUEST.fields_by_name['workspace_definition_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTWORKSPACEINSTANCESREQUEST.fields_by_name['principal']._options = None
  _LISTWORKSPACEINSTANCESREQUEST.fields_by_name['principal']._serialized_options = b'\372B\004r\002\020\001'
  _WATCHWORKSPACEINSTANCESREQUEST.oneofs_by_name['target']._options = None
  _WATCHWORKSPACEINSTANCESREQUEST.oneofs_by_name['target']._serialized_options = b'\370B\001'
  _WATCHWORKSPACEINSTANCESREQUEST.fields_by_name['org']._options = None
  _WATCHWORKSPACEINSTANCESREQUEST.fields_by_name['org']._serialized_options = b'\372B\004r\002\020\001'
  _WATCHWORKSPACEINSTANCESREQUEST.fields_by_name['project']._options = None
  _WATCHWORKSPACEINSTANCESREQUEST.fields_by_name['project']._serialized_options = b'\372B\005\212\001\002\020\001'
  _WATCHWORKSPACEINSTANCESREQUEST.fields_by_name['workspace_definition_id']._options = None
  _WATCHWORKSPACEINSTANCESREQUEST.fields_by_name['workspace_definition_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _WATCHWORKSPACEINSTANCESREQUEST.fields_by_name['workspace_instance_id']._options = None
  _WATCHWORKSPACEINSTANCESREQUEST.fields_by_name['workspace_instance_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _WATCHWORKSPACEINSTANCESREQUEST.fields_by_name['principal']._options = None
  _WATCHWORKSPACEINSTANCESREQUEST.fields_by_name['principal']._serialized_options = b'\372B\004r\002\020\001'
  _STOPWORKSPACEINSTANCEREQUEST.fields_by_name['id']._options = None
  _STOPWORKSPACEINSTANCEREQUEST.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_STARTWORKSPACEINSTANCEREQUEST']._serialized_start=272
  _globals['_STARTWORKSPACEINSTANCEREQUEST']._serialized_end=628
  _globals['_STARTWORKSPACEINSTANCERESPONSE']._serialized_start=630
  _globals['_STARTWORKSPACEINSTANCERESPONSE']._serialized_end=748
  _globals['_GETWORKSPACEINSTANCEREQUEST']._serialized_start=750
  _globals['_GETWORKSPACEINSTANCEREQUEST']._serialized_end=844
  _globals['_GETWORKSPACEINSTANCERESPONSE']._serialized_start=846
  _globals['_GETWORKSPACEINSTANCERESPONSE']._serialized_end=962
  _globals['_LISTWORKSPACEINSTANCESREQUEST']._serialized_start=965
  _globals['_LISTWORKSPACEINSTANCESREQUEST']._serialized_end=1333
  _globals['_LISTWORKSPACEINSTANCESRESPONSE']._serialized_start=1336
  _globals['_LISTWORKSPACEINSTANCESRESPONSE']._serialized_end=1478
  _globals['_WATCHWORKSPACEINSTANCESREQUEST']._serialized_start=1481
  _globals['_WATCHWORKSPACEINSTANCESREQUEST']._serialized_end=1904
  _globals['_WATCHWORKSPACEINSTANCESRESPONSE']._serialized_start=1907
  _globals['_WATCHWORKSPACEINSTANCESRESPONSE']._serialized_end=2226
  _globals['_STOPWORKSPACEINSTANCEREQUEST']._serialized_start=2228
  _globals['_STOPWORKSPACEINSTANCEREQUEST']._serialized_end=2355
  _globals['_STOPWORKSPACEINSTANCERESPONSE']._serialized_start=2357
  _globals['_STOPWORKSPACEINSTANCERESPONSE']._serialized_end=2388
# @@protoc_insertion_point(module_scope)
