# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hooks/hooks.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from union.internal.hooks import payload_pb2 as hooks_dot_payload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11hooks/hooks.proto\x12\x0e\x63loudidl.hooks\x1a\x13hooks/payload.proto2\xd6\x01\n\x0cHooksService\x12]\n\x0cStreamEvents\x12#.cloudidl.hooks.StreamEventsRequest\x1a$.cloudidl.hooks.StreamEventsResponse\"\x00\x30\x01\x12g\n\x10\x41\x63knowledgeEvent\x12\'.cloudidl.hooks.AcknowledgeEventRequest\x1a(.cloudidl.hooks.AcknowledgeEventResponse\"\x00\x42\xa5\x01\n\x12\x63om.cloudidl.hooksB\nHooksProtoH\x02P\x01Z(github.com/unionai/cloud/gen/pb-go/hooks\xa2\x02\x03\x43HX\xaa\x02\x0e\x43loudidl.Hooks\xca\x02\x0e\x43loudidl\\Hooks\xe2\x02\x1a\x43loudidl\\Hooks\\GPBMetadata\xea\x02\x0f\x43loudidl::Hooksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hooks.hooks_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022com.cloudidl.hooksB\nHooksProtoH\002P\001Z(github.com/unionai/cloud/gen/pb-go/hooks\242\002\003CHX\252\002\016Cloudidl.Hooks\312\002\016Cloudidl\\Hooks\342\002\032Cloudidl\\Hooks\\GPBMetadata\352\002\017Cloudidl::Hooks'
  _globals['_HOOKSSERVICE']._serialized_start=59
  _globals['_HOOKSSERVICE']._serialized_end=273
# @@protoc_insertion_point(module_scope)
